# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.certificates_api import CertificatesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestCertificatesApi(unittest.TestCase):
    """CertificatesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.certificates_api.CertificatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cert(self):
        """Test case for create_cert

        Creates a X509Certificate  # noqa: E501
        """
        pass

    def test_delete_agent_csr(self):
        """Test case for delete_agent_csr

        Delete a CertSigningReq  # noqa: E501
        """
        pass

    def test_delete_cert(self):
        """Test case for delete_cert

        Delete a X509Certificate  # noqa: E501
        """
        pass

    def test_delete_csr(self):
        """Test case for delete_csr

        Delete a CertSigningReq  # noqa: E501
        """
        pass

    def test_get_cert(self):
        """Test case for get_cert

        Get a X509Certificate  # noqa: E501
        """
        pass

    def test_get_csr(self):
        """Test case for get_csr

        Get a CertSigningReq  # noqa: E501
        """
        pass

    def test_list_certs(self):
        """Test case for list_certs

        list certificates  # noqa: E501
        """
        pass

    def test_list_csr(self):
        """Test case for list_csr

        list certificate signing requests  # noqa: E501
        """
        pass

    def test_replace_csr(self):
        """Test case for replace_csr

        Update a CertSigningReq  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
