# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_authz_stats import AgentConnectorAuthzStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorAuthzStats(unittest.TestCase):
    """AgentConnectorAuthzStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorAuthzStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_authz_stats.AgentConnectorAuthzStats()  # noqa: E501
        if include_optional :
            return AgentConnectorAuthzStats(
                allowed = 32, 
                allowed_app_handled = 32, 
                denied = 32, 
                token_cached_failed = 64, 
                token_cached_success = 64, 
                token_parse_failed = 64, 
                token_static_token = 64, 
                token_bad_jti = 64, 
                token_lookup_success = 64, 
                token_lookup_notfound = 64, 
                token_lookup_badrequest = 64, 
                token_lookup_4xx_other = 64, 
                token_lookup_error = 64, 
                token_lookup_revoked = 64, 
                token_basic_auth_decode_fail = 64, 
                token_basic_auth_too_long = 64, 
                token_basic_auth_no_password = 64, 
                token_basic_auth_cached_success = 64, 
                token_basic_auth_cached_failed = 64
            )
        else :
            return AgentConnectorAuthzStats(
                allowed = 32,
                allowed_app_handled = 32,
                denied = 32,
                token_cached_failed = 64,
                token_cached_success = 64,
                token_parse_failed = 64,
                token_static_token = 64,
                token_bad_jti = 64,
                token_lookup_success = 64,
                token_lookup_notfound = 64,
                token_lookup_badrequest = 64,
                token_lookup_4xx_other = 64,
                token_lookup_error = 64,
                token_lookup_revoked = 64,
                token_basic_auth_decode_fail = 64,
                token_basic_auth_too_long = 64,
                token_basic_auth_no_password = 64,
                token_basic_auth_cached_success = 64,
                token_basic_auth_cached_failed = 64,
        )

    def testAgentConnectorAuthzStats(self):
        """Test AgentConnectorAuthzStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
