# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.organisations_api import OrganisationsApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestOrganisationsApi(unittest.TestCase):
    """OrganisationsApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.organisations_api.OrganisationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_blocking_upgrade_orgs_task(self):
        """Test case for create_blocking_upgrade_orgs_task

        utility to upgrade organisations  # noqa: E501
        """
        pass

    def test_create_org(self):
        """Test case for create_org

        Create an organisation  # noqa: E501
        """
        pass

    def test_create_sub_org(self):
        """Test case for create_sub_org

        Create a sub organisation  # noqa: E501
        """
        pass

    def test_delete_sub_org(self):
        """Test case for delete_sub_org

        Delete a sub organisation  # noqa: E501
        """
        pass

    def test_get_org(self):
        """Test case for get_org

        Get a single organisation  # noqa: E501
        """
        pass

    def test_get_org_status(self):
        """Test case for get_org_status

        Get the status of an organisation  # noqa: E501
        """
        pass

    def test_list_orgs(self):
        """Test case for list_orgs

        Get all organisations  # noqa: E501
        """
        pass

    def test_list_sub_orgs(self):
        """Test case for list_sub_orgs

        Get all sub organisations  # noqa: E501
        """
        pass

    def test_replace_org(self):
        """Test case for replace_org

        Create or update an organisation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
